@@ -1,22 +1,27 @@
 /**********************************************************************
- * $Id: ParseException.h 1820 2006-09-06 16:54:23Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
- * http://geos.refractions.net
+ * http://geos.osgeo.org
  *
  * Copyright (C) 2005-2006 Refractions Research Inc.
  * Copyright (C) 2001-2002 Vivid Solutions Inc.
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU Lesser General Public Licence as published
- * by the Free Software Foundation. 
+ * by the Free Software Foundation.
  * See the COPYING file for more information.
  *
+ **********************************************************************
+ *
+ * Last port: io/ParseException.java rev. 1.13 (JTS-1.10)
+ *
  **********************************************************************/
 
 #ifndef GEOS_IO_PARSEEXCEPTION_H
 #define GEOS_IO_PARSEEXCEPTION_H
 
+#include <geos/export.h>
+
 #include <geos/util/GEOSException.h>
 
 namespace geos {
@@ -26,7 +31,7 @@ namespace io {
  * \class ParseException io.h geos.h
  * \brief Notifies a parsing error
  */
-class ParseException : public util::GEOSException
+class GEOS_DLL ParseException : public util::GEOSException
 {
 
 public:
@@ -39,7 +44,7 @@ public:
 
 	ParseException(const std::string& msg, double num);
 
-	~ParseException() throw() {};
+	~ParseException() throw() override {}
 
 private:
 	static std::string stringify(double num);
@@ -49,14 +54,3 @@ private:
 } // namespace geos
 
 #endif // #ifndef GEOS_IO_PARSEEXCEPTION_H
-
-/**********************************************************************
- * $Log$
- * Revision 1.2  2006/04/04 08:16:46  strk
- * Changed GEOSException hierarchy to be derived from std::runtime_exception.
- * Removed the GEOSException::toString redundant method (use ::what() instead)
- *
- * Revision 1.1  2006/03/20 18:18:14  strk
- * io.h header split
- *
- **********************************************************************/
