@@ -1,14 +1,13 @@
 /**********************************************************************
- * $Id: SegmentNodeList.h 3255 2011-03-01 17:56:10Z mloskot $
  *
  * GEOS - Geometry Engine Open Source
- * http://geos.refractions.net
+ * http://geos.osgeo.org
  *
  * Copyright (C) 2006      Refractions Research Inc.
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU Lesser General Public Licence as published
- * by the Free Software Foundation. 
+ * by the Free Software Foundation.
  * See the COPYING file for more information.
  *
  **********************************************************************
@@ -59,13 +58,7 @@ private:
 	std::set<SegmentNode*,SegmentNodeLT> nodeMap;
 
 	// the parent edge
-	const NodedSegmentString& edge; 
-
-	// This vector is here to keep track of created splitEdges
-	std::vector<SegmentString*> splitEdges;
-
-	// This vector is here to keep track of created Coordinates
-	std::vector<geom::CoordinateSequence*> splitCoordLists;
+	const NodedSegmentString& edge;
 
 	/**
 	 * Checks the correctness of the set of split edges corresponding
@@ -80,6 +73,8 @@ private:
 	 * (and including) the two intersections.
 	 * The label for the new edge is the same as the label for the
 	 * parent edge.
+	 *
+	 * ownership of return value is transferred
 	 */
 	SegmentString* createSplitEdge(SegmentNode *ei0, SegmentNode *ei1);
 
@@ -114,8 +109,8 @@ private:
 		size_t& collapsedVertexIndex);
 
     // Declare type as noncopyable
-    SegmentNodeList(const SegmentNodeList& other);
-    SegmentNodeList& operator=(const SegmentNodeList& rhs);
+    SegmentNodeList(const SegmentNodeList& other) = delete;
+    SegmentNodeList& operator=(const SegmentNodeList& rhs) = delete;
 
 public:
 
@@ -143,7 +138,7 @@ public:
 	 *	   destroyed at SegmentNodeList destruction time.
 	 *
 	 * @param intPt the intersection Coordinate, will be copied
-	 * @param segmentIndex 
+	 * @param segmentIndex
 	 */
 	SegmentNode* add(const geom::Coordinate& intPt, std::size_t segmentIndex);
 
@@ -196,25 +191,4 @@ std::ostream& operator<< (std::ostream& os, const SegmentNodeList& l);
 #pragma warning(pop)
 #endif
 
-//#ifdef GEOS_INLINE
-//# include "geos/noding/SegmentNodeList.inl"
-//#endif
-
 #endif
-
-/**********************************************************************
- * $Log$
- * Revision 1.4  2006/06/12 11:29:23  strk
- * unsigned int => size_t
- *
- * Revision 1.3  2006/05/04 07:41:56  strk
- * const-correct size() method for SegmentNodeList
- *
- * Revision 1.2  2006/03/24 09:52:41  strk
- * USE_INLINE => GEOS_INLINE
- *
- * Revision 1.1  2006/03/09 16:46:49  strk
- * geos::geom namespace definition, first pass at headers split
- *
- **********************************************************************/
-
